Editor Back/Forward Button Test

# Editor back/forward button value restore tests

Try typing something into the editors below, and then click the page refrsh link or the back then forward buttons. The editor should not lose the value.

Notes:

1. Editor must have a "name" attribute for this to work (not sure why)
2. If in XD mode must set dojo.config.allowXdRichTextSave or manually create the hidden <textarea> node used to preserve the data.

Navigate to another page

editor0 original contents
editor1 original contents